/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*             **** CUESTIONARIO DE CONTEXTO PARA DIRECTORES ****
/*
/*                 Ciclo escolar evaluado: 2005 - 2006
/*_____________________________________________________________________________
/*
/*   SINTXIS PARA CONSTRUIR LA BASE DE DATOS DE DIRECTORES EN FORMATO SAS
/*
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale03_2006_Dir_Cuest.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. La sintxis realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas varibles
/*   - Lectura de variables del archivo en formato ASCII
/*   - Declara los valores perdidos por el usuario (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2006_Dir_Cuest.txt
/*         as como el archivo Excale03_2006_Dir_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE.
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la libreria y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se crear la base de datos (tabla de datos) Excale03_2006_Dir_Cuest.sas7bdat.
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2006_Dir_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS carge los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE ELABORACIN: 9 DE OCTUBRE DE 2007
/*
/*  ****************************************************************************/

/*****************************************************************************
/*    ACTUALIZACIN AL 21 DE MAYO DEL 2008
/*
/*   - SE CORRIGIERON LAS ETIQUETAS DE LAS VARIABLES:
/*        sexo, edad y w_dir
/*
/*   - SE AGREGARON LAS ETIQUETAS DE LOS VALORES DE LA VARIABLE:
/*        edad
/*
/*   - SE DECLAR COMO 'PERDIDO' AL VALOR '98' DE LA VARIABLE:
/*        edad
/*
/*
/*    ACTUALIZACIN AL 15 DE AGOSTO DEL 2008
/*
/*   - SE CORRIGIERON LAS ETIQUETAS DE LOS VALORES DE LA VARIABLE:
/*        dp120
/*
/*******************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME direct "C:\***\Excale03_2006_Dir_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbanas Pblicas"
                       2         ="Rurales Pblicas"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privadas"
                       6         ="Generales"
                       7         ="Tcnicas"
                       8         ="Telesecundarias"
                       9         ="Privadas";
     VALUE  $modF      "UP"      ="Urbanas Pblicas"
                       "RP"      ="Rurales Pblicas"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privadas"
                       "GRAL"    ="Generales"
                       "TEC"     ="Tcnicas"
                       "TV"      ="Telesecundarias"
                       "PRIV"    ="Privadas";
     VALUE $entestdomF "999999"  ="Respuesta omitida";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  EdadF
                       1         ="16 aos o menos"
                       2         ="17 a 20 aos"
                       3         ="21 a 25 aos"
                       4         ="26 a 30 aos"
                       5         ="31 a 35 aos"
                       6         ="36 a 40 aos"
                       7         ="41 a 45 aos"
                       8         ="46 a 50 aos"
                       9         ="51 a 55 aos"
                       10        ="56 a 60 aos"
                       11        ="61 aos o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  d1_3F
                       1         ="El espaol"
                       2         ="Una lengua indgena (nhuatl, maya, purpecha, mixteco, otom u otra)"
                       3         ="Un idioma extranjero (francs, ingls, alemn u otro)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp004F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp005F
                       1         ="Vivo solo"
                       2         ="2"
                       3         ="3"
                       4         ="4"
                       5         ="5"
                       6         ="6"
                       7         ="7 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp006F
                       1         ="1"
                       2         ="2"
                       3         ="3"
                       4         ="4"
                       5         ="5 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp007F
                       1         ="Tierra"
                       2         ="Cemento"
                       3         ="Piso de mosaico, alfombra o duela"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d8_10F
                       0         ="No hay"
                       1         ="1"
                       2         ="2 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d11_14F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp015F
                       1         ="Primaria"
                       2         ="Secundaria"
                       3         ="Preparatoria, Bachillerato o Tcnico"
                       4         ="Licenciatura"
                       5         ="Maestra"
                       6         ="Doctorado"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d16_19F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp020F
                       1         ="1 ao o menos"
                       2         ="De 2 a 3 aos"
                       3         ="De 4 a 5 aos"
                       4         ="De 6 a 10 aos"
                       5         ="De 11 a 20 aos"
                       6         ="De 21 a 30 aos"
                       7         ="31 aos o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp021F
                       1         ="1 ao o menos"
                       2         ="De 2 a 3 aos"
                       3         ="De 4 a 5 aos"
                       4         ="De 6 a 10 aos"
                       5         ="De 11 a 20 aos"
                       6         ="De 21 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp022F
                       1         ="1"
                       2         ="2"
                       3         ="3"
                       4         ="4"
                       5         ="5 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp023F
                       1         ="Con clave o base(escuela pblica)"
                       2         ="Interino(escuela pblica)"
                       3         ="Contrato por honorarios(escuela privada)"
                       4         ="Contrato por nomina(escuela privada)"
                       5         ="Otro"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp024F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp025F
                       0         ="No"
                       1         ="S, el turno que me queda libre"
                       2         ="S, durante las vacaciones"
                       3         ="S, ocasionalmente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp026F
                       0         ="No realizo ningn otro trabajo"
                       1         ="Soy maestro en otra escuela"
                       2         ="Soy director en otra escuela"
                       3         ="Soy maestro en esta misma escuela"
                       4         ="Soy director en esta misma escuela en el otro turno"
                       5         ="Imparto cursos particulares, cursos y/o asesoras educativas"
                       6         ="Desempeo funciones no docentes en una escuela(como prefecto, apoyo administrativo, etc.)"
                       7         ="Tengo otro tipo de trabajo(comercio, bienes races, campo, empresa, etc.)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp027F
                       01        ="S"
                       00        ="No"
                       96        ="No procede(trabajo en escuela privada o en curso comunitario)"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp028F
                       96        ="No procede(trabajo en escuela privada/curso comunitario)"
                       00        ="No estoy incorporado"
                       01        ="Menos de un ao"
                       02        ="De 1 a 3"
                       03        ="De 4 a 6"
                       04        ="De 7 a 9"
                       05        ="10 o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp029F
                       96        ="No procede(trabajo en escuela privada/curso comunitario)"
                       00        ="No estoy incorporado"
                       01        ="A"
                       02        ="B"
                       03        ="BC"
                       04        ="C"
                       05        ="D"
                       06        ="E"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp030F
                       96        ="No procede(trabajo en escuela privada/curso comunitario)"
                       00        ="No estoy incorporado"
                       01        ="Docentes frente a grupo"
                       02        ="Docentes en funciones directivas o de supervisin"
                       03        ="Docentes en actualizacin tcnico-pedaggica"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp031F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp032F
                       0         ="Ninguno"
                       1         ="1"
                       2         ="2"
                       3         ="3"
                       4         ="4"
                       5         ="5 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d33_35F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp036F
                       0         ="No he tomado cursos"
                       1         ="Intiles"
                       2         ="Poco tiles"
                       3         ="tiles"
                       4         ="Muy tiles"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d37_42F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d43_48F
                       0         ="Ninguno"
                       1         ="1"
                       2         ="2"
                       3         ="3"
                       4         ="4"
                       5         ="5 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp049F
                       98       ="Respuesta mltiple"
                       99       ="Respuesta omitida"
                       998       ="Respuesta mltiple"
                       999       ="Respuesta omitida";
     VALUE  dp050F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp051F
                       1         ="Malas"
                       2         ="Regulares"
                       3         ="Buenas"
                       4         ="Excelentes"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d52_57F
                       1         ="Malo"
                       2         ="Regular"
                       3         ="Bueno"
                       4         ="Muy Bueno"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d58_63F
                       1         ="Inadecuado"
                       2         ="Adecuado"
                       3         ="Muy adecuado"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d64_70F
                       1         ="Malo"
                       2         ="Regular"
                       3         ="Bueno"
                       4         ="Muy bueno"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d71_76F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp077F
                       0         ="No se ha suspendido ni uno solo"
                       1         ="Entre 1 y 2"
                       2         ="Entre 3 y 4"
                       3         ="Entre 5 y 6"
                       4         ="7 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp078F
                       96        ="No procede, escuela unitaria"
                       00        ="No est constituido el consejo tcnico"
                       01        ="Ninguna"
                       02        ="Entre 1 y 2"
                       03        ="Entre 3 y 5"
                       04        ="Entre 6 y 7"
                       05        ="8 o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp079F
                       96        ="No procede, escuela unitaria"
                       00        ="No est constituido el consejo tcnico"
                       01        ="No se hacen reuniones"
                       02        ="Entre 1 y 2 horas"
                       03        ="Entre 3 y 4 horas"
                       04        ="5 o ms horas"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  d80_86F
                       0         ="No hay reuniones de Consejo"
                       1         ="1"
                       2         ="2"
                       3         ="3"
                       4         ="4 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d87_90F
                       1         ="S"
                       0         ="No"
                       2         ="No hay alumnos con ese problema"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp091F
                       1         ="Los mtodos de enseanza que utiliza el profesor"
                       2         ="El acompaamiento y apoyo que da la familia que da la familia en las tareas escolares"
                       3         ="El nivel econmico y social de la familia del alumno"
                       4         ="La infraestructura, el equipamiento y las condiciones del edificio de la escuela"
                       5         ="El estado de salud fsico y emocional del alumno"
                       6         ="La capacidad intelectual del alumno"
                       7         ="El cumplimiento de calendario escolar y el orden y la disciplina escolar"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d92_100F
                       0         ="No procede, escuela unitaria"
                       1         ="El director solo"
                       2         ="El director con algunos maestros"
                       3         ="Cada profesor por separado"
                       4         ="El consejo Tcnico"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp101F
                       0         ="Ninguna"
                       1         ="1"
                       2         ="2"
                       3         ="3"
                       4         ="4 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp102F
                       0         ="No se realizan juntas generales"
                       1         ="Necesidades financieras o materiales o materiales de la escuela"
                       2         ="Tipo de apoyo que se requiere de los padres para el cuidado y mantenimiento de la escuela"
                       3         ="Logro acadmico de los alumnos"
                       4         ="Orientaciones para mejorar el aprendizaje de los hijos y las relaciones padres e hijos(Escuela para Padres)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d103F
                       0         ="No se realizan"
                       1         ="Menos del 25%"
                       2         ="Entre el 25 y el 50%"
                       3         ="Entre el 50 y el 75%"
                       4         ="Ms del 75%"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp107F
                       0         ="No se elabor Proyecto Escolar"
                       1         ="Escritura y comprensin lectora"
                       2         ="Comprensin y solucin de problemas matemticos"
                       3         ="Cuidado y conservacin del medio ambiente u otra temtica relacionada con las Ciencias Naturales"
                       4         ="Educacin para los valores u otra temtica relacionada con las Ciencias Sociales"
                       5         ="Otra"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d108F
                       0         ="Ninguno"
                       1         ="Menos del 25%"
                       2         ="Entre el 25 y el 50%"
                       3         ="Entre el 50 y el 75%"
                       4         ="Ms del 75%"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d111F
                       1         ="La escuela no participa en este programa"
                       2         ="2001-2002"
                       3         ="2002-2003"
                       4         ="2003-2004"
                       5         ="2004-2005"
                       6         ="2005-2006"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp113F
                       1         ="La escuela no participa en este programa"
                       2         ="2003-2004"
                       3         ="2004-2005"
                       4         ="2005-2006"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d114F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp116F
                       96        ="No procede, escuela unitaria"
                       01        ="Visitas de diagnstico o formativas a los grupos"
                       02        ="Revisin de documentos de los profesores, planes de clase, evaluaciones, etc"
                       03        ="Reuniones con profesores"
                       04        ="Otra"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp117F
                       96        ="No procede, escuela unitaria"
                       00        ="Ninguna"
                       01        ="1"
                       02        ="2"
                       03        ="3"
                       04        ="4 o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp118F
                       96        ="No procede, escuela unitaria"
                       00        ="No he realizado visitas a los grupos"
                       01        ="Observar la clase para con base en ello retroalimentar al profesor"
                       02        ="Revisar la planeacin de la clase"
                       03        ="Revisar los cuadernillos, libros y trabajos de los alumnos"
                       04        ="Otra"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp119F
                       96        ="No procede, escuela unitaria"
                       00        ="No hice visitas a los profesores"
                       01        ="Hice visitas pero no entregu observaciones"
                       02        ="Hago comentarios verbales"
                       03        ="Doy solamente algunas notas escritas y complemento con informacin verbal"
                       04        ="Entrego un informe escrito"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp120F
                       96        ="No procede, escuela unitaria"
                       00        ="No proporciono asesora"
                       01        ="Planeacin de las clases"
                       02        ="Enfoques y estrategias de enseanza"
                       03        ="Aprovechamiento y uso de los materiales curriculares adicionales a los libros de texto(ficheros, libros para el maestro, etc.)"
                       04        ="Estrategias y tcnicas para la evaluacin"
                       05        ="Control y disciplina del grupo"
                       06        ="Aspectos de control escolar(llenado de documentos: listas, altas, bajas, boletas de calificaciones)"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp121F
                       96        ="No procede, escuela unitaria"
                       00        ="No se evala el trabajo de los profesores al final del ciclo escolar"
                       01        ="Los resultados obtenidos por los alumnos"
                       02        ="La planeacin de clases que realiz el profesor"
                       03        ="El control de grupo que tuvo el profesor"
                       04        ="La puntualidad y asistencia del profesor"
                       05        ="El uso de los materiales curriculares"
                       06        ="La metodologa de enseanza que utiliz"
                       07        ="El cumplimiento con el avance programtico"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  d122F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp126F
                       1         ="Enfoque pedaggicos para la enseanza de las asignaturas"
                       2         ="Uso de las tecnologas educativas en el aula(programas de cmputo, video, Enciclomedia, etc.)"
                       3         ="Contenidos de las materias que imparten"
                       4         ="Estrategias de evaluacin en el aula"
                       5         ="Atencin de problemticas psicolgicas de los alumnos(hiperactividad, retraso en el desarrollo, disciplina, etc.)"
                       6         ="Otro"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp127F
                       01        ="La planificacin de actividades de la escuela"
                       02        ="Las reuniones con las autoridades educativas(Supervisor, Jefe de Sector y otros)"
                       03        ="La atencin a los padres de familia"
                       04        ="La atencin de los problemas interpersonales de los miembros de la comunidad escolar(indisciplina de alumnos, conflicto entre profesores)"
                       05        ="Hacer gestiones para arreglar desperfectos de las instalaciones o del equipo escolar"
                       06        ="Realizar el seguimiento del trabajo pedaggico de la escuela(visitar los salones, revisar planes de clase, leer informe de los profesores, etc.)"
                       07        ="Las actividades administrativas(llenar documentos, elaborar informes, hacer solicitudes de materiales)"
                       08        ="Dar clases a los alumnos"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp128F
                       0         ="Ninguna"
                       1         ="Entre 1 y 4 horas"
                       2         ="Entre 5 y 10 horas"
                       3         ="Entre 11 y 15 horas"
                       4         ="Ms de 15 horas"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp129F
                       96        ="No procede, escuela unitaria"
                       01        ="Malo"
                       02        ="Regular"
                       03        ="Bueno"
                       04        ="Excelente"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  dp130F
                       1         ="Bajo"
                       2         ="Medio"
                       3         ="Alto"
                       4         ="Muy alto"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp131F
                       0         ="No existen"
                       1         ="Algunas veces"
                       2         ="Frecuentemente"
                       3         ="Siempre"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp132F
                       0         ="Nada motivados"
                       1         ="Poco motivados"
                       2         ="Motivados"
                       3         ="Muy motivados"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp133F
                       1         ="Mala"
                       2         ="Regular"
                       3         ="Buena"
                       4         ="Excelente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d134F
                       0         ="Nunca"
                       1         ="Alrededor de una vez al semestre"
                       2         ="Alrededor de una vez al mes"
                       3         ="Una vez a la semana o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d137F
                       1         ="Casi nunca"
                       2         ="Algunas veces"
                       3         ="Frecuentemente"
                       4         ="Casi siempre"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp149F
                       1         ="La baja asistencia a las reuniones y eventos que se programan"
                       2         ="El poco respeto a los acuerdos establecidos por la Mesa Directiva de la Asociacin de Padres de Familia"
                       3         ="La agresividad hacia los profesores de sus hijos"
                       4         ="La escasa comunicacin con los maestros y con la direccin de la escuela"
                       5         ="Ninguno"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  d150F
                       1         ="Muy insatisfecho"
                       2         ="Insatisfecho"
                       3         ="Satisfecho"
                       4         ="Muy satisfecho"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  dp153F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
RUN;



DATA INEE.Excale03_2006_Dir_Cuest;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $20
       id_mod             3
       mod                $4
       entest             $6
       entestdom          $6
       id_instr           $16
       sexo               3
       edad               8
       w_dir              8
       dp001              3
       dp002              3
       dp003              3
       dp004              3
       dp005              3
       dp006              3
       dp007              3
       dp008              3
       dp009              3
       dp010              3
       dp011              3
       dp012              3
       dp013              3
       dp014              3
       dp015              3
       dp016              3
       dp017              3
       dp018              3
       dp019              3
       dp020              3
       dp021              3
       dp022              3
       dp023              3
       dp024              3
       dp025              3
       dp026              3
       dp027              3
       dp028              3
       dp029              3
       dp030              3
       dp031              3
       dp032              3
       dp033              3
       dp034              3
       dp035              3
       dp036              3
       dp037              3
       dp038              3
       dp039              3
       dp040              3
       dp041              3
       dp042              3
       dp043              3
       dp044              3
       dp045              3
       dp046              3
       dp047              3
       dp048              3
       dp049              3
       dp050              3
       dp051              3
       dp052              3
       dp053              3
       dp054              3
       dp055              3
       dp056              3
       dp057              3
       dp058              3
       dp059              3
       dp060              3
       dp061              3
       dp062              3
       dp063              3
       dp064              3
       dp065              3
       dp066              3
       dp067              3
       dp068              3
       dp069              3
       dp070              3
       dp071              3
       dp072              3
       dp073              3
       dp074              3
       dp075              3
       dp076              3
       dp077              3
       dp078              3
       dp079              3
       dp080              3
       dp081              3
       dp082              3
       dp083              3
       dp084              3
       dp085              3
       dp086              3
       dp087              3
       dp088              3
       dp089              3
       dp090              3
       dp091              3
       dp092              3
       dp093              3
       dp094              3
       dp095              3
       dp096              3
       dp097              3
       dp098              3
       dp099              3
       dp100              3
       dp101              3
       dp102              3
       dp103              3
       dp104              3
       dp105              3
       dp106              3
       dp107              3
       dp108              3
       dp109              3
       dp110              3
       dp111              3
       dp112              3
       dp113              3
       dp114              3
       dp115              3
       dp116              3
       dp117              3
       dp118              3
       dp119              3
       dp120              3
       dp121              3
       dp122              3
       dp123              3
       dp124              3
       dp125              3
       dp126              3
       dp127              3
       dp128              3
       dp129              3
       dp130              3
       dp131              3
       dp132              3
       dp133              3
       dp134              3
       dp135              3
       dp136              3
       dp137              3
       dp138              3
       dp139              3
       dp140              3
       dp141              3
       dp142              3
       dp143              3
       dp144              3
       dp145              3
       dp146              3
       dp147              3
       dp148              3
       dp149              3
       dp150              3
       dp151              3
       dp152              3
       dp153              3
   ;

INFILE direct MISSOVER LINESIZE = 244;
   INPUT
       nacional       1 - 1
       escuela        2 - 5
       id_ent         6 - 7
       nom_ent        8 - 27
       id_mod        28 - 28
       mod           29 - 32
       entest        33 - 38
       entestdom     39 - 44
       Id_instr      45 - 56
       sexo          57 - 57
       edad          58 - 59
       w_dir         60 - 75
       dp001         76 - 76
       dp002         77 - 77
       dp003         78 - 78
       dp004         79 - 79
       dp005         80 - 80
       dp006         81 - 81
       dp007         82 - 82
       dp008         83 - 83
       dp009         84 - 84
       dp010         85 - 85
       dp011         86 - 86
       dp012         87 - 87
       dp013         88 - 88
       dp014         89 - 89
       dp015         90 - 90
       dp016         91 - 91
       dp017         92 - 92
       dp018         93 - 93
       dp019         94 - 94
       dp020         95 - 95
       dp021         96 - 96
       dp022         97 - 97
       dp023         98 - 98
       dp024         99 - 99
       dp025        100 - 100
       dp026        101 - 101
       dp027        102 - 103
       dp028        104 - 105
       dp029        106 - 107
       dp030        108 - 109
       dp031        110 - 110
       dp032        111 - 111
       dp033        112 - 112
       dp034        113 - 113
       dp035        114 - 114
       dp036        115 - 115
       dp037        116 - 116
       dp038        117 - 117
       dp039        118 - 118
       dp040        119 - 119
       dp041        120 - 120
       dp042        121 - 121
       dp043        122 - 122
       dp044        123 - 123
       dp045        124 - 124
       dp046        125 - 125
       dp047        126 - 126
       dp048        127 - 127
       dp049        128 - 130
       dp050        131 - 131
       dp051        132 - 132
       dp052        133 - 133
       dp053        134 - 134
       dp054        135 - 135
       dp055        136 - 136
       dp056        137 - 137
       dp057        138 - 138
       dp058        139 - 139
       dp059        140 - 140
       dp060        141 - 141
       dp061        142 - 142
       dp062        143 - 143
       dp063        144 - 144
       dp064        145 - 145
       dp065        146 - 146
       dp066        147 - 147
       dp067        148 - 148
       dp068        149 - 149
       dp069        150 - 150
       dp070        151 - 151
       dp071        152 - 152
       dp072        153 - 153
       dp073        154 - 154
       dp074        155 - 155
       dp075        156 - 156
       dp076        157 - 157
       dp077        158 - 158
       dp078        159 - 160
       dp079        161 - 162
       dp080        163 - 163
       dp081        164 - 164
       dp082        165 - 165
       dp083        166 - 166
       dp084        167 - 167
       dp085        168 - 168
       dp086        169 - 169
       dp087        170 - 170
       dp088        171 - 171
       dp089        172 - 172
       dp090        173 - 173
       dp091        174 - 174
       dp092        175 - 175
       dp093        176 - 176
       dp094        177 - 177
       dp095        178 - 178
       dp096        179 - 179
       dp097        180 - 180
       dp098        181 - 181
       dp099        182 - 182
       dp100        183 - 183
       dp101        184 - 184
       dp102        185 - 185
       dp103        186 - 186
       dp104        187 - 187
       dp105        188 - 188
       dp106        189 - 189
       dp107        190 - 190
       dp108        191 - 191
       dp109        192 - 192
       dp110        193 - 193
       dp111        194 - 194
       dp112        195 - 195
       dp113        196 - 196
       dp114        197 - 197
       dp115        198 - 198
       dp116        199 - 200
       dp117        201 - 202
       dp118        203 - 204
       dp119        205 - 206
       dp120        207 - 208
       dp121        209 - 210
       dp122        211 - 211
       dp123        212 - 212
       dp124        213 - 213
       dp125        214 - 214
       dp126        215 - 215
       dp127        216 - 217
       dp128        218 - 218
       dp129        219 - 220
       dp130        221 - 221
       dp131        222 - 222
       dp132        223 - 223
       dp133        224 - 224
       dp134        225 - 225
       dp135        226 - 226
       dp136        227 - 227
       dp137        228 - 228
       dp138        229 - 229
       dp139        230 - 230
       dp140        231 - 231
       dp141        232 - 232
       dp142        233 - 233
       dp143        234 - 234
       dp144        235 - 235
       dp145        236 - 236
       dp146        237 - 237
       dp147        238 - 238
       dp148        239 - 239
       dp149        240 - 240
       dp150        241 - 241
       dp151        242 - 242
       dp152        243 - 243
       dp153        244 - 244
   ;

   LABEL
       nacional     ="Variable auxiliar para obtener promedios nacionales"
       escuela      ="Identificador de la escuela"
       id_ent       ="Entidad federativa (identificador numrico)"
       nom_ent      ="Entidad federativa"
       id_mod       ="Estrato escolar o Modalidad educativa (identificador numrico)"
       mod          ="Estrato escolar o Modalidad educativa"
       entest       ="Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       entestdom    ="Variable auxiliar para identificar los dominios de estudio (subpoblaciones donde se reportan resultados) a nivel de modalidad al interior de las entidades"
       id_instr     ="Identificador del cuadernillo de examen"
       sexo         ="Sexo del director"
       edad         ="Edad del director en rangos"
       w_dir        ="Peso muestral o ponderador del director"
       dp001        ="Qu lengua aprendi a hablar primero?"
       dp002        ="Qu lengua habla en su casa la mayor parte del tiempo?"
       dp003        ="Qu lengua habla en su escuela la mayor parte del tiempo?"
       dp004        ="Imparte o ha impartido clases en alguna lengua indgena?"
       dp005        ="Incluyndose cuntas personas viven en su casa"
       dp006        ="El la casa donde vive, cuntos cuartos se usan para dormir?"
       dp007        ="De qu material es la mayor parte del piso de su casa?"
       dp008        ="Cuntos de los siguientes bienes tiene en su hogar? Auto, coche o camioneta"
       dp009        ="Cuntos de los siguientes bienes tiene en su hogar? Computadora"
       dp010        ="Cuntos de los siguientes bienes tiene en su hogar? Televisin"
       dp011        ="Su hogar cuenta con... Drenaje"
       dp012        ="Su hogar cuenta con... Lnea Telefnica"
       dp013        ="Su hogar cuenta con... Internet"
       dp014        ="Su hogar cuenta con... Horno de microondas"
       dp015        ="Cul es su nivel mximo de estudios?"
       dp016        ="Cul es su formacin especfica para la docencia? Marque en cada una de las opciones si curs o no estos estudios. Cursos de nivelacin pedaggica"
       dp017        ="Cul es su formacin especfica para la docencia? Marque en cada una de las opciones si curs o no estos estudios. Bachillerato pedaggico"
       dp018        ="Cul es su formacin especfica para la docencia? Marque en cada una de las opciones si curs o no estos estudios. Normal bsica sin licenciatura"
       dp019        ="Cul es su formacin especfica para la docencia? Marque en cada una de las opciones si curs o no estos estudios. Normal superior o Licenciatura en educacin"
       dp020        ="Contando este ciclo escolar, cuntos aos en total tiene de trabajar como director? (Sin importar en qu escuela)"
       dp021        ="Contando este ciclo escolar, cuntos aos tiene de trabajar como director en esta escuela?"
       dp022        ="En cuntas escuelas ha desempeado usted el cargo de director?"
       dp023        ="Qu tipo de plaza o contrato de trabajo tiene actualmente en esta escuela?"
       dp024        ="Adems de su funcin como director, desempea usted la funcin de profesor frente a grupo en esta misma escuela y turno?"
       dp025        ="Adems de su funcin como director, desempea usted otro trabajo remunerado?"
       dp026        ="Principalmente, qu tipo de trabajo realiza?"
       dp027        ="Est usted incorporado al programa de estmulos de Carrera Magisterial del SEP?"
       dp028        ="Cuntos aos lleva incorporado al Programa de Estmulos de Carrera Magisterial de la SEP?"
       dp029        ="En que nivel del Programa de Carrera Magisterial de la SEP se encuentra actualmente?"
       dp030        ="En qu vertiente del programa de Carrera Magisterial de la SEP se encuentra actualmente"
       dp031        ="Si no est incorporado a Carrera Magisterial, participa en algn programa donde reciba un estmulo econmico adicional a su salario?"
       dp032        ="En los ltimos dos aos, a cuntos cursos de capacitacin o actualizacin relacionados con su actividad directiva ha asistido?"
       dp033        ="En los ltimos dos aos, ha tomado cursos relacionados con las siguientes temticas? Marque en cada opcin si o no. Gestin escolar"
       dp034        ="En los ltimos dos aos, ha tomado cursos relacionados con las siguientes temticas? Marque en cada opcin si o no. Enfoques sobre el trabajo en las asignaturas"
       dp035        ="En los ltimos dos aos, ha tomado cursos relacionados con las siguientes temticas? Marque en cada opcin si o no. Evaluacin educativa"
       dp036        ="Qu tan tiles para el ejercicio de sus funciones como director han sido los conocimientos adquiridos en los cursos que han tomado en los dos ltimos aos"
       dp037        ="Cules de os grados de la educacin primaria se imparten en esta escuela? Marque si o no para cada uno de los grados. Primero"
       dp038        ="Cules de os grados de la educacin primaria se imparten en esta escuela? Marque si o no para cada uno de los grados. Segundo"
       dp039        ="Cules de os grados de la educacin primaria se imparten en esta escuela? Marque si o no para cada uno de los grados. Tercero"
       dp040        ="Cules de os grados de la educacin primaria se imparten en esta escuela? Marque si o no para cada uno de los grados. Cuarto"
       dp041        ="Cules de os grados de la educacin primaria se imparten en esta escuela? Marque si o no para cada uno de los grados. Quinto"
       dp042        ="Cules de os grados de la educacin primaria se imparten en esta escuela? Marque si o no para cada uno de los grados. Sexto"
       dp043        ="Cuntos grupos hay por cada grado? Para cada grado, rellene el crculo que corresponda a la cantidad de grupos. Primero"
       dp044        ="Cuntos grupos hay por cada grado? Para cada grado, rellene el crculo que corresponda a la cantidad de grupos. Segundo"
       dp045        ="Cuntos grupos hay por cada grado? Para cada grado, rellene el crculo que corresponda a la cantidad de grupos. Tercero"
       dp046        ="Cuntos grupos hay por cada grado? Para cada grado, rellene el crculo que corresponda a la cantidad de grupos. Cuarto"
       dp047        ="Cuntos grupos hay por cada grado? Para cada grado, rellene el crculo que corresponda a la cantidad de grupos. Quinto"
       dp048        ="Cuntos grupos hay por cada grado? Para cada grado, rellene el crculo que corresponda a la cantidad de grupos. Sexto"
       dp049        ="Cuntos profesores frente a grupo hay en esta primaria? Si usted como director tiene grupos a su cargo inclyase. Escriba la cantidad"
       dp050        ="En esta escuela, hay profesores frente a grupo que impartan clases a alumnos de dos grados o ms en una misma aula?"
       dp051        ="En su opinin, cmo son las condiciones generales de la escuela en cuanto a infraestructura, equipamiento y recursos didcticos?"
       dp052        ="En qu estado se encuentran los siguientes espacios? El edificio en general"
       dp053        ="En qu estado se encuentran los siguientes espacios? El mobiliario para alumnos"
       dp054        ="En qu estado se encuentran los siguientes espacios? Las aulas"
       dp055        ="En qu estado se encuentran los siguientes espacios? La biblioteca"
       dp056        ="En qu estado se encuentran los siguientes espacios? El(los) patio(s)"
       dp057        ="En qu estado se encuentran los siguientes espacios? Los baos para alumnos"
       dp058        ="Indique cul es el grado de adecuacin de los siguientes espacios. Considere el nmero de usuarios. el edificio en general"
       dp059        ="Indique cul es el grado de adecuacin de los siguientes espacios. Considere el nmero de usuarios. El mobiliario para alumnos"
       dp060        ="Indique cul es el grado de adecuacin de los siguientes espacios. Considere el nmero de usuarios. Las aulas"
       dp061        ="Indique cul es el grado de adecuacin de los siguientes espacios. Considere el nmero de usuarios. La biblioteca"
       dp062        ="Indique cul es el grado de adecuacin de los siguientes espacios. Considere el nmero de usuarios. El(los) patio(s)"
       dp063        ="Indique cul es el grado de adecuacin de los siguientes espacios. Considere el nmero de usuarios. Los baos para alumnos"
       dp064        ="Indique el estado de la mayora de las aulas en relacin con los siguientes aspectos: Mesabancos o pupitres"
       dp065        ="Indique el estado de la mayora de las aulas en relacin con los siguientes aspectos: Pizarrones"
       dp066        ="Indique el estado de la mayora de las aulas en relacin con los siguientes aspectos: Iluminacin"
       dp067        ="Indique el estado de la mayora de las aulas en relacin con los siguientes aspectos: Temperatura"
       dp068        ="Indique el estado de la mayora de las aulas en relacin con los siguientes aspectos: Aislamiento del ruido"
       dp069        ="Indique el estado de la mayora de las aulas en relacin con los siguientes aspectos: Ventilacin"
       dp070        ="Indique el estado de la mayora de las aulas en relacin con los siguientes aspectos: Superficie con relacin a la cantidad de alumnos"
       dp071        ="En el presente ciclo escolar,  recibi con oportunidad los materiales de la SEP?(libros para alumnos, libros para maestros, etc)."
       dp072        ="Indique si los siguientes materiales son suficientes: Libros de texto para los alumnos"
       dp073        ="Indique si los siguientes materiales son suficientes: Libros para el maestro"
       dp074        ="Indique si los siguientes materiales son suficientes: Plan y programas de estudio para docentes"
       dp075        ="Indique si los siguientes materiales son suficientes: Avances programticos"
       dp076        ="Indique si los siguientes materiales son suficientes: Ficheros para docentes"
       dp077        ="En este ciclo escolar, Cuntos das de clases se han suspendido en su escuela?(no cuente los das obligados por la SEP)."
       dp078        ="Durante el presente ciclo escolar, cuntas reuniones de Consejo Tcnico se han realizado?"
       dp079        ="Regularmente, qu duracin tiene las reuniones de Consejo Tcnico en esta escuela?"
       dp080        ="En cuntas de las reuniones de Consejo Tcnico se han abordado las siguientes temticas? Prctica pedaggica"
       dp081        ="En cuntas de las reuniones de Consejo Tcnico se han abordado las siguientes temticas? Administracin de la escuela"
       dp082        ="En cuntas de las reuniones de Consejo Tcnico se han abordado las siguientes temticas? Cuidado y mantenimiento de la escuela"
       dp083        ="En cuntas de las reuniones de Consejo Tcnico se han abordado las siguientes temticas? Manejo, control y disciplina del grupo"
       dp084        ="En cuntas de las reuniones de Consejo Tcnico se han abordado las siguientes temticas? Relacin de la escuela o los profesores con los padres de familia"
       dp085        ="En cuntas de las reuniones de Consejo Tcnico se han abordado las siguientes temticas? Organizacin de eventos y festejos escolares"
       dp086        ="En cuntas de las reuniones de Consejo Tcnico se han abordado las siguientes temticas? Situaciones laborales de los docentes"
       dp087        ="Seale si en la escuela se instrumentan acciones especificas para atender a los alumnos que presentan lo siguientes problemas: Alumnos con dificultades de aprendizaje"
       dp088        ="Seale si en la escuela se instrumentan acciones especificas para atender a los alumnos que presentan lo siguientes problemas: Alumnos con problemas severos de conducta"
       dp089        ="Seale si en la escuela se instrumentan acciones especificas para atender a los alumnos que presentan lo siguientes problemas: Alumnos con discapacidades(problemas de sordera, ceguera, motrices, etc.)"
       dp090        ="Seale si en la escuela se instrumentan acciones especificas para atender a los alumnos que presentan lo siguientes problemas: Alumnos repetidores"
       dp091        ="Considerando las caractersticas de esta escuela, Cul considera que es el factor que ms influye en el aprendizaje de los alumnos?"
       dp092        ="En esta escuela, quin(es) toman(n) predominantemente las decisiones sobre los siguientes aspectos de su organizacin? Asignar profesores a grados y grupos"
       dp093        ="En esta escuela, quin(es) toman(n) predominantemente las decisiones sobre los siguientes aspectos de su organizacin? Tomar medidas en casos de indisciplina grave de los alumnos"
       dp094        ="En esta escuela, quin(es) toman(n) predominantemente las decisiones sobre los siguientes aspectos de su organizacin? Definir las formas de evaluar el rendimiento de los alumnos"
       dp095        ="En esta escuela, quin(es) toman(n) predominantemente las decisiones sobre los siguientes aspectos de su organizacin? Definir los criterios de aprobacin/reprobacin de los alumnos"
       dp096        ="En esta escuela, quin(es) toman(n) predominantemente las decisiones sobre los siguientes aspectos de su organizacin? Escojer los libros complementarios que llevar cada grado"
       dp097        ="En esta escuela, quin(es) toman(n) predominantemente las decisiones sobre los siguientes aspectos de su organizacin? Elegir la temtica a atender en el Proyecto Escolar"
       dp098        ="En esta escuela, quin(es) toman(n) predominantemente las decisiones sobre los siguientes aspectos de su organizacin? Decidir sobre actividades de formacin para los profesores"
       dp099        ="En esta escuela, quin(es) toman(n) predominantemente las decisiones sobre los siguientes aspectos de su organizacin? Definir los criterios para evaluar el desempeo de los profesores"
       dp100        ="En esta escuela, quin(es) toman(n) predominantemente las decisiones sobre los siguientes aspectos de su organizacin? Decidir sobre las mejoras a realizar en el edificio de la escuela"
       dp101        ="Cuntas juntas escolares generales con padres de familia se han realizado durante el presente ciclo escolar?"
       dp102        ="Cul es el tema que con mayor frecuencia se trata en las juntas escolares generales?"
       dp103        ="En el presente ciclo escolar, aproximadamente qu porcentaje de padres de familia han acudido a las siguientes actividades de la escuela? Reuniones de la Asociacin de Padres de Familia"
       dp104        ="En el presente ciclo escolar, aproximadamente qu porcentaje de padres de familia han acudido a las siguientes actividades de la escuela? Actividades escolares como ceremonias cvicas, festivales o eventos deportivos"
       dp105        ="En el presente ciclo escolar, aproximadamente qu porcentaje de padres de familia han acudido a las siguientes actividades de la escuela? Juntas escolares para brindar informacin general dar talleres o conferencias a padres, firmar boletas de calificaciones, etc."
       dp106        ="En el presente ciclo escolar, aproximadamente qu porcentaje de padres de familia han acudido a las siguientes actividades de la escuela? Citas individuales con el maestro o el director para tratar asuntos de los alumnos"
       dp107        ="Cul es la temtica principal que aborda el Proyecto Escolar en el presente ciclo escolar?"
       dp108        ="En su escuela, aproximadamente qu porcentaje de los alumnos estn siendo beneficiados por alguno de los siguientes programas? Desayunos escolares"
       dp109        ="En su escuela, aproximadamente qu porcentaje de los alumnos estn siendo beneficiados por alguno de los siguientes programas? Programa Oportunidades"
       dp110        ="En su escuela, aproximadamente qu porcentaje de los alumnos estn siendo beneficiados por alguno de los siguientes programas? Programa de becas del estado o municipio"
       dp111        ="Desde qu ciclo escolar la escuela participa en el Programa Escuelas de Calidad?"
       dp112        ="Desde qu ciclo escolar la escuela es beneficiada con las bibliotecas de Aula del Programa Nacional de Lectura?"
       dp113        ="Desde qu ciclo escolar al escuela participa en el programa Enciclomedia?"
       dp114        ="La escuela es beneficiada por el PAREIB?"
       dp115        ="La escuela es beneficiada por los programas de Educacin de Educacin Especial(atencin a alumnos con problemas de aprendizaje o con capacidades diferentes)?"
       dp116        ="Cul es la actividad principal que realiza para conocer cmo estn trabajando los profesores de su escuela?"
       dp117        ="En promedio, en que ciclo escolar, Cuntas visitas de diagnstico y/o para retroalimentacin ha realizado a cada uno de los grupos y profesores de su escuela?"
       dp118        ="Cul es la actividad que realiza predominantemente cuando visita los grupos?"
       dp119        ="De qu manera da a conocer a los profesores las observaciones que hace cuando visita los grupos?"
       dp120        ="Cul es el tema principal sobre el que usted asesora a los profesores?"
       dp121        ="Al final del ao escolar, Cul es el criterio principal que utiliza para evaluar el trabajo de los profesores de su escuela?"
       dp122        ="De las siguientes acciones, cules se realizan en su escuela para promover la actualizacin de los profesores? Se invita a participar en los cursos de PRONAP"
       dp123        ="De las siguientes acciones, cules se realizan en su escuela para promover la actualizacin de los profesores? Se piden cursos especiales al Centro de Maestros"
       dp124        ="De las siguientes acciones, cules se realizan en su escuela para promover la actualizacin de los profesores? La escuela organiza cursos para los profesores con especialistas"
       dp125        ="De las siguientes acciones, cules se realizan en su escuela para promover la actualizacin de los profesores? Se asiste a los cursos que convoca la supervisin"
       dp126        ="Para este ciclo escolar, Cul es el principal tema o aspecto sobre el que los profesores y/o usted necesitan capacitacin o actualizacin?"
       dp127        ="En este mes, cul de las actividades que se enuncian a continuacin le demando ms tiempo?"
       dp128        ="En promedio, Cuntas horas adicionales a las de su contrato o plaza le demanda por semana su trabajo como director"
       dp129        ="En su opinin, cmo es el nivel de comunicacin entre los docentes de esta escuela?"
       dp130        ="En su opinin, cmo es el nivel de exigencia acadmica de los docentes de esta escuela?"
       dp131        ="Con qu frecuencia se aplican las normas de disciplina en la escuela"
       dp132        ="En su opinin, qu tan motivado para aprender estn los alumnos de esta escuela?"
       dp133        ="Cmo es la disciplina de la mayora de los grupos de la escuela?"
       dp134        ="Durante el presente ciclo escolar, qu tan seguido se han presentado robos de objetos o dinero dentro de la escuela?"
       dp135        ="Durante el presente ciclo escolar,  qu tan seguido los alumnos han daado las instalaciones, el mobiliario o el equipo de la escuela?"
       dp136        ="Durante el presente ciclo escolar, qu tan seguido los alumnos han participado en peleas a golpes dentro de la escuela?"
       dp137        ="En el presente ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los profesores? Inasistencia de los profesores"
       dp138        ="En el presente ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los profesores? Uso poco efectivo del tiempo de clases"
       dp139        ="En el presente ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los profesores? Falta de preparacin de sus clases"
       dp140        ="En el presente ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los profesores? Dificultad para controlar los grupos"
       dp141        ="En el presente ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los profesores? Falta de dominio de los enfoques de las asignaturas"
       dp142        ="En el presente ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los profesores? Falta de dominio de los contenidos de las asignaturas"
       dp143        ="En el presente ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los profesores? Cambios frecuentes de docentes a otras escuelas(rotacin de profesores)"
       dp144        ="En el presente ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los profesores? Mala relacin entre los profesores"
       dp145        ="En este ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los alumnos? Inasistencia"
       dp146        ="En este ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los alumnos? Reprobacin"
       dp147        ="En este ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los alumnos? Desercin"
       dp148        ="En este ciclo escolar, con qu frecuencia se han presentado los siguientes problemas con respecto a los alumnos? Indisciplina"
       dp149        ="En el presente ciclo escolar, cul es el principal problema que hay en la escuela con respecto a los padres de familia? "
       dp150        ="Qu tan satisfecho se encuentra de la remuneracin econmica que recibe como director en esta escuela?"
       dp151        ="Qu tan satisfecho se encuentra de trabajar como director de esta escuela?"
       dp152        ="Qu tan satisfecho se encuentra de trabajar con sus compaeros docentes?"
       dp153        ="Quisiera cambiarse de escuela el prximo ciclo escolar?"
   ;

   FORMAT
       nacional      1.
       escuela       4.
       id_ent        id_entF.
       nom_ent       $char20.
       id_mod        id_modF.
       mod           $modF.
       entest        $char6.
       entestdom     $entestdomF.
       id_instr      $char16.
       sexo          sexoF.
       edad          edadF.
       dp001         d1_3F.
       dp002         d1_3F.
       dp003         d1_3F.
       dp004         dp004F.
       dp005         dp005F.
       dp006         dp006F.
       dp007         dp007F.
       dp008         d8_10F.
       dp009         d8_10F.
       dp010         d8_10F.
       dp011         d11_14F.
       dp012         d11_14F.
       dp013         d11_14F.
       dp014         d11_14F.
       dp015         dp015F.
       dp016         d16_19F.
       dp017         d16_19F.
       dp018         d16_19F.
       dp019         d16_19F.
       dp020         dp020F.
       dp021         dp021F.
       dp022         dp022F.
       dp023         dp023F.
       dp024         dp024F.
       dp025         dp025F.
       dp026         dp026F.
       dp027         dp027F.
       dp028         dp028F.
       dp029         dp029F.
       dp030         dp030F.
       dp031         dp031F.
       dp032         dp032F.
       dp033         d33_35F.
       dp034         d33_35F.
       dp035         d33_35F.
       dp036         dp036F.
       dp037         d37_42F.
       dp038         d37_42F.
       dp039         d37_42F.
       dp040         d37_42F.
       dp041         d37_42F.
       dp042         d37_42F.
       dp043         d43_48F.
       dp044         d43_48F.
       dp045         d43_48F.
       dp046         d43_48F.
       dp047         d43_48F.
       dp048         d43_48F.
       dp049         dp049F.
       dp050         dp050F.
       dp051         dp051F.
       dp052         d52_57F.
       dp053         d52_57F.
       dp054         d52_57F.
       dp055         d52_57F.
       dp056         d52_57F.
       dp057         d52_57F.
       dp058         d58_63F.
       dp059         d58_63F.
       dp060         d58_63F.
       dp061         d58_63F.
       dp062         d58_63F.
       dp063         d58_63F.
       dp064         d64_70F.
       dp065         d64_70F.
       dp066         d64_70F.
       dp067         d64_70F.
       dp068         d64_70F.
       dp069         d64_70F.
       dp070         d64_70F.
       dp071         d71_76F.
       dp072         d71_76F.
       dp073         d71_76F.
       dp074         d71_76F.
       dp075         d71_76F.
       dp076         d71_76F.
       dp077         dp077F.
       dp078         dp078F.
       dp079         dp079F.
       dp080         d80_86F.
       dp081         d80_86F.
       dp082         d80_86F.
       dp083         d80_86F.
       dp084         d80_86F.
       dp085         d80_86F.
       dp086         d80_86F.
       dp087         d87_90F.
       dp088         d87_90F.
       dp089         d87_90F.
       dp090         d87_90F.
       dp091         dp091F.
       dp092         d92_100F.
       dp093         d92_100F.
       dp094         d92_100F.
       dp095         d92_100F.
       dp096         d92_100F.
       dp097         d92_100F.
       dp098         d92_100F.
       dp099         d92_100F.
       dp100         d92_100F.
       dp101         dp101F.
       dp102         dp102F.
       dp103         d103F.
       dp104         d103F.
       dp105         d103F.
       dp106         d103F.
       dp107         dp107F.
       dp108         d108F.
       dp109         d108F.
       dp110         d108F.
       dp111         d111F.
       dp112         d111F.
       dp113         dp113F.
       dp114         d114F.
       dp115         d114F.
       dp116         dp116F.
       dp117         dp117F.
       dp118         dp118F.
       dp119         dp119F.
       dp120         dp120F.
       dp121         dp121F.
       dp122         d122F.
       dp123         d122F.
       dp124         d122F.
       dp125         d122F.
       dp126         dp126F.
       dp127         dp127F.
       dp128         dp128F.
       dp129         dp129F.
       dp130         dp130F.
       dp131         dp131F.
       dp132         dp132F.
       dp133         dp133F.
       dp134         d134F.
       dp135         d134F.
       dp136         d134F.
       dp137         d137F.
       dp138         d137F.
       dp139         d137F.
       dp140         d137F.
       dp141         d137F.
       dp142         d137F.
       dp143         d137F.
       dp144         d137F.
       dp145         d137F.
       dp146         d137F.
       dp147         d137F.
       dp148         d137F.
       dp149         dp149F.
       dp150         d150F.
       dp151         d150F.
       dp152         d150F.
       dp153         dp153F.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Multiple.
/*   .S o S = No contestado.
/*************************************************************************/
   IF entestdom = "999999"  THEN entestdom = "S";
   IF  edad = 99 THEN  edad = .S;
   IF  edad = 98 THEN  edad = .M;

   ARRAY perdidos1(139) sexo  dp001 dp002 dp003 dp004 dp005 dp006 dp007 dp008 dp009
                        dp010 dp011 dp012 dp013 dp014 dp015 dp016 dp017 dp018 dp019
                        dp020 dp021 dp022 dp023 dp024 dp025 dp026 dp031 dp032 dp033
                        dp034 dp035 dp036 dp037 dp038 dp039 dp040 dp041 dp042 dp043
                        dp044 dp045 dp046 dp047 dp048 dp050 dp051 dp052 dp053 dp054
                        dp055 dp056 dp057 dp058 dp059 dp060 dp061 dp062 dp063 dp064
                        dp065 dp066 dp067 dp068 dp069 dp070 dp071 dp072 dp073 dp074
                        dp075 dp076 dp077 dp080 dp081 dp082 dp083 dp084 dp085 dp086
                        dp087 dp088 dp089 dp090 dp091 dp092 dp093 dp094 dp095 dp096
                        dp097 dp098 dp099 dp100 dp101 dp102 dp103 dp104 dp105 dp106
                        dp107 dp108 dp109 dp110 dp111 dp112 dp113 dp114 dp115 dp122
                        dp123 dp124 dp125 dp126 dp128 dp130 dp131 dp132 dp133 dp134
                        dp135 dp136 dp137 dp138 dp139 dp140 dp141 dp142 dp143 dp144
                        dp145 dp146 dp147 dp148 dp149 dp150 dp151 dp152 dp153 ;
   DO  i=1 TO 139;
         IF perdidos1{i}=8 THEN  perdidos1{i}= .M;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(14) dp027 dp028 dp029 dp030
                       dp078 dp079 dp116 dp117 dp118
                       dp119 dp120 dp121 dp127 dp129;
   DO  i=1 TO 14;
         IF perdidos2{i}=98 THEN  perdidos2{i}= .M;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;
   IF  dp049 = 998 THEN  dp049 = .M;
   IF  dp049 = 999 THEN  dp049 = .S;



   drop i;
RUN;
